==> postman_2.0.orig.tar.gz: postman/Service_PersonalData.cc <==
/*                               
Service_PersonalData.cc
*/

#include "Service_PersonalData.h"

#include "ClientHTTP.h"

extern Language *L;
extern Configuration *Conf;

bool Service_PersonalData_Initialized = false;

#define PERSONALDATA_HOST    "bancuv.uv.es"
#define PERSONALDATA_PORT    80
#define PERSONALDATA_TIMEOUT 3
#define PASSWORD "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
#define URL2GetFoto "/fotoini/"
#define URL2GetName "/cgi-bin/get_nombre/"

TPersonalInfo PersonalInfo;

class HTMLPages: public HTMLBasic
  {
  private:
    //
  public:
    void PrintPersonalDataDisplayPage (const char *stlang, const char *user, const char *connid, UserOptions *uo, StringList *SLRes);
  };

//retrieve the url for the Service icon
const char *GetService_PersonalData_ICO_URL (void)
  {
  return "";
  }

//Retrieve the ALT tag for the Service icon
const char *GetService_PersonalData_ICO_ALT (void)
  {
  return "";
  }

//Retrieve the Service name
const char *GetService_PersonalData_NAME (void)
  {
  return "";
  }

//Retrieve the Service Description
const char *GetService_PersonalData_DESCRIPTION (void)
  {
  return "";
  }

//Entry point to service init
bool DoService_PersonalData_BEGIN (TProgData *pd)
  {
  TBuffer file2show, toencript, bufencriptado, header2send;
  int ir, maxbufencriptado = CMAXBUFFER, httpcode;
  StringList SLHTTPHead, SLHTTPBody;
  ClientHTTP *CliHTTP;
  bool b;

  if (Service_PersonalData_Initialized == true) {return true;}
  
  initStr (PersonalInfo.Name);
  initStr (PersonalInfo.PAN);  
  initStr (PersonalInfo.NPI);  
  initStr (PersonalInfo.RefFoto);  
  initStr (PersonalInfo.URLFoto);  

  if (CheckServiceDisabled (TranslateServiceR(pd->service), file2show) == true) 
    {pd->html->dumpFile (file2show, "TEXT/HTML"); return false;}        
  LOG ("Initializating Service PersonalData for user=%s", pd->username);

  ir = Rand (strlen(PASSWORD));
  xsnprintf (toencript, CMAXBUFFER, "%.3d:%s:%s:%s:", ir, pd->username, pd->username, "postman");
  encryptcasero (PASSWORD, toencript, strlen(toencript), bufencriptado, &maxbufencriptado);

  /*PHOTO IMG SRC*/
  xsnprintf (PersonalInfo.URLFoto, CMAXBUFFER, "%s%s", URL2GetFoto, bufencriptado);

  /*USER FIRST ANS SECOND NAME*/
  CliHTTP = new ClientHTTP (PERSONALDATA_HOST, PERSONALDATA_PORT, PERSONALDATA_TIMEOUT);
  sprintf (header2send, "GET %s%s HTTP/1.0\n\n", URL2GetName, bufencriptado);
  b = CliHTTP->doGetHTTPSL (header2send, &SLHTTPHead, &SLHTTPBody, &httpcode);
  if (b == true)
    {      
    if (SLHTTPBody.Count() > 0) 
      {
      xstrncpy (PersonalInfo.Name, CMAXBUFFER, SLHTTPBody.getString(0).cstr());
      Rtrim (PersonalInfo.Name);
      }
    }
  else
    {
    Service_PersonalData_Initialized = false;
    }    
  delete CliHTTP;

  Service_PersonalData_Initialized = true;
  return true;
  }

//Entry point to service end
bool DoService_PersonalData_END (TProgData *pd)
  {
  Service_PersonalData_Initialized = false;
  return true;
  }

//Entry point to execute a service command
bool DoService_PersonalData_CMD (TProgData *pd)
  {
  HTMLPages *html;
  int cmd;

  html = (HTMLPages *)pd->html;

  TBuffer file2show;
  if (CheckServiceDisabled (TranslateServiceR(pd->service), file2show) == true) 
    {pd->html->dumpFile (file2show, "TEXT/HTML"); return false;}        

  cmd = pd->cmd;
    
  switch (pd->cmd)
    {
    default: 
      {    
      LOG ("ERROR: Service_PersonalData: Here we can not go!! cmd=%s, subcmd=%s", pd->stcmd, pd->stsubcmd);
      pd->html->PrintInvalidCommand (pd->stlang, pd->username, pd->connid, pd->uo);
      break;
      }         
    }
  return false;  
  }  

bool getPersonalInfo (const char *token_name, TBuffer tokeninfo)
  {
  TBuffer uptoken;
  initStr (tokeninfo);
  if (IsEmpty(token_name)) {return false;}
  xstrncpy (uptoken, CMAXBUFFER, token_name); xucase (uptoken);
  
  if (strcmp (uptoken, "NAME")== 0)         {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.Name);}
  else if (strcmp (uptoken, "PAN")== 0)     {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.PAN);}
  else if (strcmp (uptoken, "NPI")== 0)     {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.NPI);}
  else if (strcmp (uptoken, "REFFOTO")== 0) {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.RefFoto);}
  else if (strcmp (uptoken, "URLFOTO")== 0) {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.URLFoto);}
  else {return false;}
  
  if (IsEmpty(tokeninfo)) return false; 
  else return true;  
  }

void HTMLPages::PrintPersonalDataDisplayPage (const char *stlang, const char *user, const char *connid, UserOptions *uo, StringList *SLRes)
  {
  
  }

==> postman_2.1.orig.tar.gz: postman/Service_PersonalData.cc <==
/*                               
Service_PersonalData.cc
*/

#include "Service_PersonalData.h"

#include "ClientHTTP.h"

extern Language *L;
extern Configuration *Conf;

bool Service_PersonalData_Initialized = false;

#define PERSONALDATA_HOST    "bancuv.uv.es"
#define PERSONALDATA_PORT    80
#define PERSONALDATA_TIMEOUT 3
//#define PASSWORD "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
#define PASSWORD "Una que estoy probando en estos momentos. Espero que sea suficientemente larga."
#define URL2GetFoto "/fotoini/"
#define URL2GetName "/cgi-bin/get_nombre/"

TPersonalInfo PersonalInfo;

class HTMLPages: public HTMLBasic
  {
  private:
    //
  public:
    void PrintPersonalDataDisplayPage (const char *stlang, const char *user, const char *connid, UserOptions *uo, StringList *SLRes);
  };

//retrieve the url for the Service icon
const char *GetService_PersonalData_ICO_URL (void)
  {
  return "";
  }

//Retrieve the ALT tag for the Service icon
const char *GetService_PersonalData_ICO_ALT (void)
  {
  return "";
  }

//Retrieve the Service name
const char *GetService_PersonalData_NAME (void)
  {
  return "";
  }

//Retrieve the Service Description
const char *GetService_PersonalData_DESCRIPTION (void)
  {
  return "";
  }

//Entry point to service init
bool DoService_PersonalData_BEGIN (TProgData *pd)
  {
  TBuffer file2show, toencript, bufencriptado, header2send;
  int ir, maxbufencriptado = CMAXBUFFER, httpcode;
  StringList SLHTTPHead, SLHTTPBody;
  ClientHTTP *CliHTTP;
  bool b;

  if (Service_PersonalData_Initialized == true) {return true;}
  
  initStr (PersonalInfo.Name);
  initStr (PersonalInfo.PAN);  
  initStr (PersonalInfo.NPI);  
  initStr (PersonalInfo.RefFoto);  
  initStr (PersonalInfo.URLFoto);  

  if (CheckServiceDisabled (TranslateServiceR(pd->service), file2show) == true) 
    {pd->html->dumpFile (file2show, "TEXT/HTML"); return false;}        
  LOG ("Initializating Service PersonalData for user=%s", pd->username);

  ir = Rand (strlen(PASSWORD));
  xsnprintf (toencript, CMAXBUFFER, "%.3d:%s:%s:%s:", ir, pd->username, pd->username, "postman");
  encryptcasero (PASSWORD, toencript, strlen(toencript), bufencriptado, &maxbufencriptado);

  /*PHOTO IMG SRC*/
  xsnprintf (PersonalInfo.URLFoto, CMAXBUFFER, "%s%s", URL2GetFoto, bufencriptado);

  /*USER FIRST ANS SECOND NAME*/
  CliHTTP = new ClientHTTP (PERSONALDATA_HOST, PERSONALDATA_PORT, PERSONALDATA_TIMEOUT);
  sprintf (header2send, "GET %s%s HTTP/1.0\n\n", URL2GetName, bufencriptado);
  b = CliHTTP->doGetHTTPSL (header2send, &SLHTTPHead, &SLHTTPBody, &httpcode);
  if (b == true)
    {      
    if (SLHTTPBody.Count() > 0) 
      {
      xstrncpy (PersonalInfo.Name, CMAXBUFFER, SLHTTPBody.getString(0).cstr());
      Rtrim (PersonalInfo.Name);
      }
    }
  else
    {
    Service_PersonalData_Initialized = false;
    }    
  delete CliHTTP;

  Service_PersonalData_Initialized = true;
  return true;
  }

//Entry point to service end
bool DoService_PersonalData_END (TProgData *pd)
  {
  Service_PersonalData_Initialized = false;
  return true;
  }

//Entry point to execute a service command
bool DoService_PersonalData_CMD (TProgData *pd)
  {
  HTMLPages *html;
  int cmd;

  html = (HTMLPages *)pd->html;

  TBuffer file2show;
  if (CheckServiceDisabled (TranslateServiceR(pd->service), file2show) == true) 
    {pd->html->dumpFile (file2show, "TEXT/HTML"); return false;}        

  cmd = pd->cmd;
    
  switch (pd->cmd)
    {
    default: 
      {    
      LOG ("ERROR: Service_PersonalData: Here we can not go!! cmd=%s, subcmd=%s", pd->stcmd, pd->stsubcmd);
      pd->html->PrintInvalidCommand (pd->stlang, pd->username, pd->connid, pd->uo);
      break;
      }         
    }
  return false;  
  }  

bool getPersonalInfo (const char *token_name, TBuffer tokeninfo)
  {
  TBuffer uptoken;
  initStr (tokeninfo);
  if (IsEmpty(token_name)) {return false;}
  xstrncpy (uptoken, CMAXBUFFER, token_name); xucase (uptoken);
  
  if (strcmp (uptoken, "NAME")== 0)         {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.Name);}
  else if (strcmp (uptoken, "PAN")== 0)     {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.PAN);}
  else if (strcmp (uptoken, "NPI")== 0)     {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.NPI);}
  else if (strcmp (uptoken, "REFFOTO")== 0) {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.RefFoto);}
  else if (strcmp (uptoken, "URLFOTO")== 0) {xstrncpy (tokeninfo, CMAXBUFFER, PersonalInfo.URLFoto);}
  else {return false;}
  
  if (IsEmpty(tokeninfo)) return false; 
  else return true;  
  }

void HTMLPages::PrintPersonalDataDisplayPage (const char *stlang, const char *user, const char *connid, UserOptions *uo, StringList *SLRes)
  {
  
  }
